rnalysis.filtering.FoldChangeFilter.filter\_by\_ref\_table\_attr
================================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: FoldChangeFilter.filter_by_ref_table_attr